@@ -87,7 +87,6 @@
  */
 #include "nautilus-desktop-window.h"
 
-#define STATUS_BAR_CLEAR_TIMEOUT 10000	/* milliseconds */
 #define MAX_HISTORY_ITEMS 50
 
 /* FIXME bugzilla.gnome.org 41245: hardwired sizes */
@@ -190,8 +189,9 @@ nautilus_window_instance_init (NautilusWindow *window)
 	/* Register IconFactory callback to update the window border icon
 	 * when the icon-theme is changed.
 	 */
-	g_signal_connect (nautilus_icon_factory_get (), "icons_changed",
-			  G_CALLBACK (icons_changed_callback), window);
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (icons_changed_callback), window,
+				 0);
 
 	/* Create a separate component so when we remove the status
 	 * we don't loose the status bar
@@ -337,7 +337,6 @@ nautilus_window_clear_status (gpointer callback_data)
 	window = NAUTILUS_WINDOW (callback_data);
 
 	bonobo_ui_component_set_status (window->details->status_ui, NULL, NULL);
-	window->status_bar_clear_id = 0;
 
 	return FALSE;
 }
@@ -345,17 +344,10 @@ nautilus_window_clear_status (gpointer callback_data)
 void
 nautilus_window_set_status (NautilusWindow *window, const char *text)
 {
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
-
 	if (text != NULL && text[0] != '\0') {
 		bonobo_ui_component_set_status (window->details->status_ui, text, NULL);
-		window->status_bar_clear_id = g_timeout_add
-			(STATUS_BAR_CLEAR_TIMEOUT, nautilus_window_clear_status, window);
 	} else {
 		nautilus_window_clear_status (window);
-		window->status_bar_clear_id = 0;
 	}
 }
 
@@ -970,10 +962,6 @@ nautilus_window_finalize (GObject *object)
 		g_object_unref (window->last_location_bookmark);
 	}
 
-	if (window->status_bar_clear_id != 0) {
-		g_source_remove (window->status_bar_clear_id);
-	}
-
 	bonobo_object_unref (window->details->ui_container);
 
 	if (window->details->location_change_at_idle_id != 0) {
@@ -1177,7 +1165,7 @@ add_view_as_bonobo_menu_item (NautilusWindow *window,
 		(window->details->shell_ui,
 		 placeholder_path,
 		 index,
-		 identifier->view_as_label,
+		 identifier->view_as_label_with_mnemonic,
 		 "viewers group");
 
 	tip = g_strdup_printf (_("Display this location with \"%s\""),
